package com.example.patientmonitoring;

import androidx.appcompat.app.AppCompatActivity;
import androidx.recyclerview.widget.LinearLayoutManager;
import androidx.recyclerview.widget.RecyclerView;

import android.graphics.Color;
import android.os.Bundle;
import android.util.Log;

import com.android.volley.Request;
import com.android.volley.Response;
import com.android.volley.VolleyError;
import com.android.volley.toolbox.StringRequest;
import com.android.volley.toolbox.Volley;
import com.example.patientmonitoring.Prevalent.Patients;
import com.example.patientmonitoring.Prevalent.Result;
import com.github.mikephil.charting.charts.LineChart;
import com.github.mikephil.charting.data.Entry;
import com.github.mikephil.charting.data.LineData;
import com.github.mikephil.charting.data.LineDataSet;
import com.github.mikephil.charting.interfaces.datasets.ILineDataSet;

import org.json.JSONArray;
import org.json.JSONException;
import org.json.JSONObject;

import java.util.ArrayList;
import java.util.List;

public class HistoryActivity extends AppCompatActivity {

    private RecyclerView recyclerView;
    private List<Result> resultList;
    LineChart systolicChart, respitoryChart, diastolicChart, tempChart, heartRateChart;
    public ArrayList<Entry> dataSystolic = new ArrayList<Entry>();
    public ArrayList<Entry> dataDiastolic= new ArrayList<Entry>();
    public ArrayList<Entry> dataRespiratory = new ArrayList<Entry>();
    public ArrayList<Entry> dataTemp = new ArrayList<Entry>();
    public ArrayList<Entry> dataHeartRate = new ArrayList<Entry>();

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_history);

        systolicChart = findViewById(R.id.systolicChart);
        respitoryChart = findViewById(R.id.respitoryChart);
        tempChart = findViewById(R.id.tempChart);
        diastolicChart = findViewById(R.id.diastolicChart);
        heartRateChart = findViewById(R.id.heartRateChart);

        recyclerView = findViewById(R.id.recycler_avpu);
        recyclerView.setHasFixedSize(true);
        recyclerView.setLayoutManager(new LinearLayoutManager(this));

        resultList = new ArrayList<>();

        final String getCaretakerID = getIntent().getStringExtra("caretaker_id");
        final String getPatientID = getIntent().getStringExtra("patient_id");

        getSupportActionBar().setTitle("History Parient ID: "+getPatientID);

        loadResult(getPatientID);

    }

    private void loadResult(String patientID) {
        String newURL = "http://192.168.0.100/android/getResult.php"+"?user="+patientID;
        Log.d("check", newURL);
        StringRequest stringRequest = new StringRequest(Request.Method.GET, newURL,
                new Response.Listener<String>() {
                    @Override
                    public void onResponse(String response) {
                        int index;
                        Log.d("check", response);
                        try {
                            //converting the string to json array object
                            JSONArray array = new JSONArray(response);
                            //traversing through all the object

                            if(array.length()>7)
                                 index = array.length() - 7;
                            else
                                index=0;

                            for (int i = index; i < array.length(); i++) {

                                //getting product object from json array
                                JSONObject result = array.getJSONObject(i);

                                dataSystolic.add(new Entry(i, Integer.parseInt(result.getString("systolic"))));
                                dataTemp.add(new Entry(i, Integer.parseInt(result.getString("temperature"))));
                                dataDiastolic.add(new Entry(i, Integer.parseInt(result.getString("diastolic"))));
                                dataHeartRate.add(new Entry(i, Integer.parseInt(result.getString("heart_rate"))));
                                dataRespiratory.add(new Entry(i, Integer.parseInt(result.getString("respiration_rate"))));

                                resultList.add(new Result(
                                        result.getString("systolic"),
                                        result.getString("diastolic"),
                                        result.getString("respiration_rate"),
                                        result.getString("temperature"),
                                        result.getString("heart_rate"),
                                        result.getString("AVPU"),
                                        result.getString("score"),
                                        result.getString("date")
                                ));

                                //creating adapter object and setting it to recyclerview
                                ResultAdapter adapter = new ResultAdapter(HistoryActivity.this, resultList);
                                recyclerView.setAdapter(adapter);

                                if(i == array.length()-1){
                                    renderCharts();
                                }
                            }
                        } catch (JSONException e) {
                            //Log.d("check", e.getMessage());
                            e.printStackTrace();
                        }
                    }
                },
                new Response.ErrorListener() {
                    @Override
                    public void onErrorResponse(VolleyError error) {

                    }
                });

        //adding our stringrequest to queue
        Volley.newRequestQueue(this).add(stringRequest);
    }

    private void renderCharts(){
        LineDataSet lineDataSet = new LineDataSet(dataSystolic, "Systolic BP");
        ArrayList<ILineDataSet> iLineDataSets= new ArrayList<>();
        iLineDataSets.add(lineDataSet);

        LineDataSet lineDataSetRespiratory = new LineDataSet(dataRespiratory, "Respiratory Rate");
        ArrayList<ILineDataSet> iLineDataSets1= new ArrayList<>();
        iLineDataSets1.add(lineDataSetRespiratory);

        LineDataSet lineDataSetHeart= new LineDataSet(dataHeartRate, "Heart Rate");
        ArrayList<ILineDataSet> iLineDataSets2= new ArrayList<>();
        iLineDataSets2.add(lineDataSetHeart);

        LineDataSet lineDataSetDiastolic= new LineDataSet(dataDiastolic, "Diastolic");
        ArrayList<ILineDataSet> iLineDataSets3= new ArrayList<>();
        iLineDataSets3.add(lineDataSetDiastolic);

        LineDataSet lineDataSetTemperature= new LineDataSet(dataTemp, "Temperature");
        ArrayList<ILineDataSet> iLineDataSets4= new ArrayList<>();
        iLineDataSets4.add(lineDataSetTemperature);

        LineData lineData = new LineData(iLineDataSets);
        systolicChart.setData(lineData);
        systolicChart.invalidate();

        LineData lineData1 = new LineData(iLineDataSets1);
        respitoryChart.setData(lineData1);
        respitoryChart.invalidate();

        LineData lineData2 = new LineData(iLineDataSets2);
        heartRateChart.setData(lineData2);
        heartRateChart.invalidate();

        LineData lineData3 = new LineData(iLineDataSets3);
        diastolicChart.setData(lineData3);
        diastolicChart.invalidate();

        LineData lineData4 = new LineData(iLineDataSets4);
        tempChart.setData(lineData4);
        tempChart.invalidate();

        //systolicChart.setBackgroundColor(Color.CYAN);
        //systolicChart.setNoDataText("Data Not Available");

        lineDataSet.setColor(Color.RED);
        lineDataSet.setCircleColor(Color.RED);
        lineDataSet.setDrawCircles(true);
        lineDataSet.setDrawCircleHole(true);
        lineDataSet.setLineWidth(5);
        lineDataSet.setCircleRadius(10);
        lineDataSet.setCircleHoleRadius(10);
        lineDataSet.setValueTextSize(10);
        lineDataSet.setValueTextColor(Color.BLACK);

        lineDataSetRespiratory.setColor(Color.BLUE);
        lineDataSetRespiratory.setCircleColor(Color.BLUE);
        lineDataSetRespiratory.setDrawCircles(true);
        lineDataSetRespiratory.setDrawCircleHole(true);
        lineDataSetRespiratory.setLineWidth(5);
        lineDataSetRespiratory.setCircleRadius(10);
        lineDataSetRespiratory.setCircleHoleRadius(10);
        lineDataSetRespiratory.setValueTextSize(10);
        lineDataSetRespiratory.setValueTextColor(Color.BLACK);

        lineDataSetHeart.setColor(Color.YELLOW);
        lineDataSetHeart.setCircleColor(Color.YELLOW);
        lineDataSetHeart.setDrawCircles(true);
        lineDataSetHeart.setDrawCircleHole(true);
        lineDataSetHeart.setLineWidth(5);
        lineDataSetHeart.setCircleRadius(10);
        lineDataSetHeart.setCircleHoleRadius(10);
        lineDataSetHeart.setValueTextSize(10);
        lineDataSetHeart.setValueTextColor(Color.BLACK);

        lineDataSetDiastolic.setColor(Color.GREEN);
        lineDataSetDiastolic.setCircleColor(Color.GREEN);
        lineDataSetDiastolic.setDrawCircles(true);
        lineDataSetDiastolic.setDrawCircleHole(true);
        lineDataSetDiastolic.setLineWidth(5);
        lineDataSetDiastolic.setCircleRadius(10);
        lineDataSetDiastolic.setCircleHoleRadius(10);
        lineDataSetDiastolic.setValueTextSize(10);
        lineDataSetDiastolic.setValueTextColor(Color.BLACK);

        lineDataSetTemperature.setColor(Color.CYAN);
        lineDataSetTemperature.setCircleColor(Color.CYAN);
        lineDataSetTemperature.setDrawCircles(true);
        lineDataSetTemperature.setDrawCircleHole(true);
        lineDataSetTemperature.setLineWidth(5);
        lineDataSetTemperature.setCircleRadius(10);
        lineDataSetTemperature.setCircleHoleRadius(10);
        lineDataSetTemperature.setValueTextSize(10);
        lineDataSetTemperature.setValueTextColor(Color.BLACK);
    }
}