package com.example.patientmonitoring;

import android.content.Intent;
import android.os.Bundle;
import android.util.Log;
import android.view.Menu;
import android.view.MenuItem;
import android.view.View;
import android.widget.ImageView;
import android.widget.ListView;
import android.widget.ProgressBar;
import android.widget.TextView;
import android.widget.Toast;

import androidx.appcompat.app.ActionBar;
import androidx.appcompat.app.AppCompatActivity;
import androidx.appcompat.widget.Toolbar;
import androidx.core.app.NavUtils;
import androidx.recyclerview.widget.GridLayoutManager;
import androidx.recyclerview.widget.LinearLayoutManager;
import androidx.recyclerview.widget.RecyclerView;

import com.android.volley.Request;
import com.android.volley.Response;
import com.android.volley.VolleyError;
import com.android.volley.toolbox.StringRequest;
import com.android.volley.toolbox.Volley;
import com.example.patientmonitoring.Prevalent.Patients;

import org.json.JSONArray;
import org.json.JSONException;
import org.json.JSONObject;

import java.util.ArrayList;
import java.util.List;

import io.paperdb.Paper;

public class PatientListActivity extends AppCompatActivity {

    private ImageView btn_addnewpatient;
    private RecyclerView recyclerView;
    private List<Patients> patientList;
    final String user_id = Paper.book().read("user_id");
    private String BASE_URL = "http://192.168.0.100/android/getpatient.php";

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_patient_list);
        Paper.init(this);
        getSupportActionBar().setTitle("Patient List");


        btn_addnewpatient = findViewById(R.id.img_addnewpatient);
        recyclerView = findViewById(R.id.patients_recyclerView);
        recyclerView.setHasFixedSize(true);
        recyclerView.setLayoutManager(new LinearLayoutManager(this));

        patientList = new ArrayList<>();

        loadPatients();

        btn_addnewpatient.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View view) {
                Intent intent = new Intent(PatientListActivity.this, AddPatientActivity.class);
                startActivity(intent);
            }
        });
    }

    @Override
    public boolean onCreateOptionsMenu(Menu menu){
        getMenuInflater().inflate(R.menu.homee, menu);
        return true;
    }

    @Override
    public boolean onOptionsItemSelected(MenuItem item){
        switch (item.getItemId()){
            case android.R.id.home:
                NavUtils.navigateUpFromSameTask(this);
                return true;
            case R.id.action_editprofile:
                startActivity(new Intent(this, ProfileCaretakerActivity.class));
                return true;
            case R.id.action_logout:
                Paper.book().delete("user");
                startActivity(new Intent(this, LoginActivity.class));
                finish();
                return true;
        }
        return super.onOptionsItemSelected(item);
    }

    private void loadPatients() {
        String newURL = BASE_URL+"?user="+user_id;
        Log.d("check", newURL);
        StringRequest stringRequest = new StringRequest(Request.Method.GET, newURL,
                new Response.Listener<String>() {
                    @Override
                    public void onResponse(String response) {
                        Log.d("check", response);
                        try {
                            //converting the string to json array object
                            JSONArray array = new JSONArray(response);
                            //traversing through all the object
                            for (int i = 0; i < array.length(); i++) {

                                //getting product object from json array
                                JSONObject patient = array.getJSONObject(i);

                                //adding the product to product list
                                patientList.add(new Patients(
                                        patient.getString("patient_id"),
                                        patient.getString("name"),
                                        patient.getString("age"),
                                        patient.getString("gender"),
                                        patient.getString("address"),
                                        patient.getString("latest_score")
                                ));
                            }

                            //creating adapter object and setting it to recyclerview
                            PatientListRecycler adapter = new PatientListRecycler(PatientListActivity.this, patientList);
                            recyclerView.setAdapter(adapter);
                        } catch (JSONException e) {
                            //Log.d("check", e.getMessage());
                            e.printStackTrace();
                        }
                    }
                },
                new Response.ErrorListener() {
                    @Override
                    public void onErrorResponse(VolleyError error) {

                    }
                });

        //adding our stringrequest to queue
        Volley.newRequestQueue(this).add(stringRequest);
    }

}
